---
title: "Urubu 1.1.0 released"
layout: page 
date: 2016-01-10
---

This release adds experimental support for the `<mark`> tag.

Read more in the manual: [/manual/extensions#Support for the mark tag]
and in [this blog post][post].

[post]: http://www.jandecaluwe.com/blog/mark-tag-support.html

